@@ -11,6 +11,9 @@ best practices. Typeclass-specific information can be found in their respective
 modules.
 -}
 module Data.Deriving (
+      -- * Backported changes
+      -- $changes
+
       -- * @derive@- functions
       -- $derive
 
@@ -19,9 +22,52 @@ module Data.Deriving (
       module Exports
     ) where
 
+import Data.Bounded.Deriving     as Exports
+import Data.Enum.Deriving        as Exports
+import Data.Eq.Deriving          as Exports
 import Data.Foldable.Deriving    as Exports
 import Data.Functor.Deriving     as Exports
+import Data.Ix.Deriving          as Exports
+import Data.Ord.Deriving         as Exports
 import Data.Traversable.Deriving as Exports
+import Text.Read.Deriving        as Exports
+import Text.Show.Deriving        as Exports
+
+{- $changes
+The following changes have been backported:
+
+* In GHC 7.2, deriving 'Read' was changed so that constructors that use
+  @MagicHash@ now parse correctly.
+
+* In GHC 7.8, deriving standalone 'Read' instances was fixed to avoid crashing on
+  datatypes with no constructors. Derived 'Read' instances were also changed so
+  as to compile more quickly.
+
+* In GHC 7.10, deriving standalone 'Read' and 'Show' instances were fixed to ensure
+  that they use the correct fixity information for a particular datatype.
+
+* In GHC 8.0, @DeriveFoldable@ was changed to allow folding over data types with
+  existential constraints.
+
+* In GHC 8.0, @DeriveFoldable@ and @DeriveTraversable@ were changed so as not to
+  generate superfluous 'mempty' or 'pure' expressions in generated code. As a result,
+  this allows deriving 'Traversable' instances for datatypes with unlifted argument
+  types.
+
+* In GHC 8.0, deriving 'Ix' was changed to use @('&&')@ instead of @if@, as the latter
+  interacts poorly with @RebindableSyntax@. A bug was also fixed so that
+  standalone-derived 'Ix' instances for single-constructor GADTs do not crash GHC.
+
+* In GHC 8.0, deriving 'Show' was changed so that constructor fields with unlifted
+  types are no longer shown with parentheses, and the output of showing an unlifted
+  type is suffixed with the same number of hash signs as the corresponding primitive
+  literals.
+
+* In GHC 8.2, deriving 'Ord' was changed so that it generates concrete @if@-expressions
+  that are not subject to @RebindableSyntax@. It was also changed so that derived
+  @('<=')@, @('>')@, and @('>=')@ methods are expressed through @('<')@, which avoids
+  generating a substantial amount of code.
+-}
 
 {- $derive
 
@@ -62,7 +108,7 @@ $('deriveFunctor' 'AssocDataInt1) -- instance Functor (AssocData Int) where ...
 @derive@-functions in @deriving-compat@ fall into one of three categories:
 
 * Category 0: Typeclasses with an argument of kind @*@.
-  ('deriveEq', 'deriveOrd', 'deriveRead', 'deriveShow')
+  ('deriveBounded', 'deriveEnum', 'deriveEq', 'deriveIx', 'deriveOrd', 'deriveRead', 'deriveShow')
 
 * Category 1: Typeclasses with an argument of kind @* -> *@, That is, a datatype
   with such an instance must have at least one type variable, and the last type
